from flask_wtf import FlaskForm
from app.models import Restaurant, PaymentType
from wtforms import StringField, PasswordField, BooleanField, SubmitField, SelectField, IntegerField, DateField
from wtforms.validators import DataRequired, Email, EqualTo, Length, NumberRange, Regexp, InputRequired


class OrderForm(FlaskForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        restaurants = Restaurant.query.all()
        self.restaurant.choices = [r.name for r in restaurants if r.active]

        payment_types = PaymentType.query.all()
        self.customer_payment_type.choices = [p.name for p in payment_types]

    date = DateField("Date")
    restaurant = SelectField("Restaurant")
    receipt = IntegerField("Receipt #", validators=[InputRequired(), NumberRange(min=0, max=10000)])
    customer_addr = StringField('Customer Address', validators=[InputRequired(), Length(0, 64)])
    driver_paid = StringField("Driver Paid", validators=[InputRequired(), Regexp(r"^[0-9]*\.?[0-9]{0,2}$")], default="0.00")
    restaurant_total = StringField("Restaurant Total", validators=[InputRequired(), Regexp(r"^[0-9]*\.?[0-9]{0,2}$")], default="0.00")
    tips = StringField("Tips", validators=[InputRequired(), Regexp(r"^[0-9]*\.?[0-9]{0,2}$")], default="0.00")
    customer_payment_type = SelectField("Payment Type")
    additional_pickup = BooleanField("Additional Pickup?")
    last_order = BooleanField("Driver's last order of the day?", default=False)
    submit = SubmitField('Submit')


class EditOrderForm(FlaskForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        restaurants = Restaurant.query.all()
        payment_types = PaymentType.query.all()
        self.restaurant.choices = [r.name for r in restaurants if r.active]
        self.customer_payment_type.choices = [p.name for p in payment_types]

    date = DateField("Date")
    restaurant = SelectField("Restaurant")
    receipt = IntegerField("Receipt #", validators=[InputRequired(), NumberRange(min=0, max=10000)])
    customer_address = StringField('Customer Address', validators=[InputRequired(), Length(1,64)])
    driver_paid_amount = StringField("Driver Paid", validators=[InputRequired(), Regexp(r"^[0-9]*\.?[0-9]{0,2}$")])
    total_restaurant_amount = StringField("Restaurant Total", validators=[InputRequired(), Regexp(r"^[0-9]*\.?[0-9]{0,2}$")])
    tips = StringField("Tips", validators=[InputRequired(), Regexp(r"^[0-9]*\.?[0-9]{0,2}$")])
    customer_payment_type = SelectField("Payment Type")
    additional_pickup = BooleanField("Additional Pickup?")
    last_order = BooleanField("Driver's last order of the day?", default=False)
    submit = SubmitField('Submit')


class ChooseReportForm(FlaskForm):
    username = StringField('Username', validators=[DataRequired()])
    email = StringField('Email', validators=[DataRequired(), Email()])
    password = PasswordField('Password', validators=[DataRequired()])
    password2 = PasswordField('Repeat Password', validators=[DataRequired(), EqualTo('password')])
    submit = SubmitField('Register')


class DailyDriverReportForm(FlaskForm):
    username = StringField('Username', validators=[DataRequired()])
    email = StringField('Email', validators=[DataRequired(), Email()])
    password = PasswordField('Password', validators=[DataRequired()])
    password2 = PasswordField('Repeat Password', validators=[DataRequired(), EqualTo('password')])
    submit = SubmitField('Register')


class MonthlyRestaurantReportForm(FlaskForm):
    email = StringField('Email', validators=[DataRequired(), Email()])
    submit = SubmitField('Request Password Reset')
